@@ -180,6 +180,8 @@ typedef struct _XimDefICValues {
 #define	XIM_FALSE	False
 #define	XIM_OVERFLOW	(-1)
 
+#define BRL_UC_ROW	0x2800
+
 /*
  * Global symbols
  */
@@ -670,6 +672,10 @@ extern int	_XimLcctstoutf8(
     Status	*state
 );
 
+extern char _XimGetMyEndian(
+    void
+);
+
 extern int	_XimCheckDataSize(
     XPointer	 buf,
     int		 len
